package com.nsgk.agentcentersdk.api;

import com.nsgk.agentcentersdk.utility.NSConv;

// SDK全局环境
public final class NSSDK
{
    // client
    private static final ThreadLocal<String> _host = new ThreadLocal<>();
    private static final ThreadLocal<Short> _port = new ThreadLocal<>();
    private static final ThreadLocal<String>  _identifier = new ThreadLocal<>();
    private static final ThreadLocal<Boolean> _clientInit = new ThreadLocal<>();
    private static final ThreadLocal<String> _publicKey = new ThreadLocal<>();

    // server
    private static final ThreadLocal<String> _privateKey = new ThreadLocal<>();
    private static final ThreadLocal<Boolean> _serverInit = new ThreadLocal<>();

    public static boolean InitClient(String host, short port, String identifier, String publicKey)
    {
        if(NSConv.FALSE(_clientInit.get()))
            return false;
        _host.set(host);
        _port.set(port);
        _identifier.set(identifier);
        _publicKey.set(publicKey);
        _clientInit.set(true);
        return true;
    }

    public static boolean ShutdownClient()
    {
        if(NSConv.FALSE(_clientInit.get()))
            return false;
        _host.remove();
        _port.remove();
        _identifier.remove();
        _publicKey.remove();
        _clientInit.set(false);
        return true;
    }

    public static String Host()
    {
        return _host.get();
    }

    public static short Port()
    {
        return _port.get();
    }

    public static String Identifier()
    {
        return _identifier.get();
    }

    public static NSSDKClient InstanceClient()
    {
        if(!NSConv.FALSE(_clientInit.get()))
            return null;
        return new NSSDKClient(_host.get(), _port.get(), _identifier.get(), _publicKey.get());
    }


    public static boolean InitServer(String privateKey)
    {
        if(NSConv.FALSE(_serverInit.get()))
            return false;
        _privateKey.set(privateKey);
        _serverInit.set(true);
        return true;
    }

    public static boolean ShutdownServer()
    {
        if(NSConv.FALSE(_serverInit.get()))
            return false;
        _privateKey.remove();
        _serverInit.set(false);
        return true;
    }

    public static NSSDKServer InstanceServer()
    {
        if(!NSConv.FALSE(_serverInit.get()))
            return null;
        return new NSSDKServer(_privateKey.get());
    }
}
