package com.nsgk.agentcentersdk.api;

import com.nsgk.agentcentersdk.core.NSReportObject;
import com.nsgk.agentcentersdk.entity.NSEntityBase;
import com.nsgk.agentcentersdk.err.NSAssert;
import com.nsgk.agentcentersdk.err.NSErrGlobal;
import com.nsgk.agentcentersdk.err.NSErrno;
import com.nsgk.agentcentersdk.utility.NSArr;
import com.nsgk.agentcentersdk.utility.NSCrypto;
import com.nsgk.agentcentersdk.utility.NSHttp;

import javax.servlet.http.HttpServletRequest;

// SDK服务端
public final class NSSDKServer
{
    private final String privateKey;

    public NSSDKServer(String privateKey)
    {
        this.privateKey = privateKey;
    }

    // 解析请求
    public <T extends NSEntityBase> NSReportObject<T> Recv(HttpServletRequest request, Class<T> clazz)
    {
        NSReportObject<T> res;
        String sign;
        String data;

        sign = request.getHeader("sign");
        NSAssert.NotEmpty(sign, NSErrno.ERRNO_CLI_SIGN_MISSING);
        data = NSHttp.GetRequestBody(request);
        NSAssert.NotEmpty(data, NSErrno.ERRNO_CLI_DATA_MISSING);
        res = new NSReportObject<>();
        res.SetTimestampStr(request.getParameter("timestamp"))
                .setIdentifier(request.getParameter("identifier"))
                .SetProtocolStr(request.getParameter("protocol"))
        ;
        try
        {
            data = NSCrypto.RSADecrypt(data, privateKey);
            NSAssert.NotEmpty(data, NSErrno.ERRNO_SYS_DECRYPT_FAIL);
            res.SetDataStr(data, clazz);
        }
        catch(Exception e)
        {
            e.printStackTrace();
            return NSErrGlobal.ThrowAndReturnNull(NSErrno.ERRNO_SYS_DECRYPT_FAIL);
        }
        if(!res.CheckSign(sign))
        {
            return NSErrGlobal.ThrowAndReturn(NSErrno.ERRNO_SYS_INVALID_SIGN, null);
        }
        res.setSign(sign);
        return res;
    }

    // 响应客户端
    public static NSApiResult Resp(int code, String msg, Object...data)
    {
        return new NSApiResult(code, msg, NSArr.DefParm(data));
    }

    public static NSApiResult Success(String msg, Object...data)
    {
        return NSApiResult.Success(msg, NSArr.DefParm(data));
    }

    public static NSApiResult Fail(int errno, String msg, Object...data)
    {
        return NSApiResult.Error(errno, msg, NSArr.DefParm(data));
    }

}
