package com.ruoyi.agentcenter.service.impl;

import java.util.List;
import com.ruoyi.common.utils.DateUtils;
import org.apache.commons.collections4.ListUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.agentcenter.mapper.TAgentTaskMapper;
import com.ruoyi.agentcenter.domain.TAgentTask;
import com.ruoyi.agentcenter.service.ITAgentTaskService;
import org.springframework.transaction.annotation.Transactional;

/**
 * 任务清单Service业务层处理
 * 
 * @author zhao
 * @date 2023-05-06
 */
@Service
public class TAgentTaskServiceImpl implements ITAgentTaskService 
{
    @Autowired
    private TAgentTaskMapper tAgentTaskMapper;

    /**
     * 查询任务清单
     * 
     * @param id 任务清单主键
     * @return 任务清单
     */
    @Override
    public TAgentTask selectTAgentTaskById(Long id)
    {
        return tAgentTaskMapper.selectTAgentTaskById(id);
    }

    /**
     * 查询任务清单列表
     * 
     * @param tAgentTask 任务清单
     * @return 任务清单
     */
    @Override
    public List<TAgentTask> selectTAgentTaskList(TAgentTask tAgentTask)
    {
        return tAgentTaskMapper.selectTAgentTaskList(tAgentTask);
    }

    /**
     * 新增任务清单
     * 
     * @param tAgentTask 任务清单
     * @return 结果
     */
    @Override
    public int insertTAgentTask(TAgentTask tAgentTask)
    {
        tAgentTask.setCreateTime(DateUtils.getNowDate());
        return tAgentTaskMapper.insertTAgentTask(tAgentTask);
    }

    /**
     * 批量新增任务清单
     *
     * @param list 任务清单
     * @return 结果
     */
    @Override
    @Transactional
    public int insertTAgentTaskBatch(List<TAgentTask> list){
        List<List<TAgentTask>> splists = ListUtils.partition(list, 50);
        splists.forEach(splist->{
            tAgentTaskMapper.insertTAgentTaskBatch(splist);
        });
        return 1;
    }

    /**
     * 修改任务清单
     * 
     * @param tAgentTask 任务清单
     * @return 结果
     */
    @Override
    public int updateTAgentTask(TAgentTask tAgentTask)
    {
        tAgentTask.setUpdateTime(DateUtils.getNowDate());
        return tAgentTaskMapper.updateTAgentTask(tAgentTask);
    }

    /**
     * 批量修改 任务清单
     *
     * @param list 任务清单
     * @return 结果
     */
    @Override
    @Transactional
    public int updateTAgentTaskBatch(List<TAgentTask> list) {
        List<List<TAgentTask>> splists = ListUtils.partition(list, 50);
        splists.forEach(splist->{
            tAgentTaskMapper.updateTAgentTaskBatch(splist);
        });
        return 1;
    }

    /**
     * 批量删除任务清单
     * 
     * @param ids 需要删除的任务清单主键
     * @return 结果
     */
    @Override
    public int deleteTAgentTaskByIds(Long[] ids)
    {
        return tAgentTaskMapper.deleteTAgentTaskByIds(ids);
    }

    /**
     * 删除任务清单信息
     * 
     * @param id 任务清单主键
     * @return 结果
     */
    @Override
    public int deleteTAgentTaskById(Long id)
    {
        return tAgentTaskMapper.deleteTAgentTaskById(id);
    }

    // Harm
    /**
     * 单条条件查询任务清单
     *
     * @param tAgentTask 任务清单
     * @return 任务清单条目
     */
    @Override
    public TAgentTask selectTAgentTask(TAgentTask tAgentTask) {
        return tAgentTaskMapper.selectTAgentTask(tAgentTask);
    }

    /**
     * 条件查询任务清单数量
     *
     * @param tAgentTask 任务清单
     * @return 任务清单数量
     */
    @Override
    public Long selectTAgentTaskCount(TAgentTask tAgentTask) {
        return tAgentTaskMapper.selectTAgentTaskCount(tAgentTask);
    }

    /**
     * 条件查询任务清单是否存在
     *
     * @param tAgentTask 任务清单
     * @return 任务清单是否存在
     */
    @Override
    public boolean selectTAgentTaskExists(TAgentTask tAgentTask) {
        return tAgentTaskMapper.selectTAgentTaskExists(tAgentTask) > 0;
    }
}
